@@ -165,6 +165,10 @@ static NSMutableDictionary *authentifiedHosts;
     int attempts = 1;
     int ret = kVLCWifiAuthentificationBanned;
 
+    if (host == nil) {
+        return kVLCWifiAuthentificationFailure;
+    }
+
     @synchronized (authentificationAttemptsHosts) {
         if ([authentificationAttemptsHosts objectForKey:host]) {
             attempts += [[authentificationAttemptsHosts objectForKey:host] intValue];
@@ -423,6 +427,10 @@ static NSMutableDictionary *authentifiedHosts;
 - (HTTPDynamicFileResponse *)generateXMLResponseFrom:(NSArray *)media path:(NSString *)path
 {
     NSMutableArray *mediaInXml = [[NSMutableArray alloc] initWithCapacity:media.count];
+    /* form a strict character set to produce a valid XML stream */
+    NSMutableCharacterSet *characterSet = [[NSMutableCharacterSet alloc] init];
+    [characterSet formUnionWithCharacterSet:NSCharacterSet.URLFragmentAllowedCharacterSet];
+    [characterSet removeCharactersInString:@"!#$%&'()*+,/:;=?@[]"];
     NSString *hostName = [NSString stringWithFormat:@"%@:%@", [[VLCHTTPUploaderController sharedInstance] hostname], [[VLCHTTPUploaderController sharedInstance] hostnamePort]];
     for (NSObject <VLCMLObject> *mediaObject in media) {
         if ([mediaObject isKindOfClass:[VLCMLMedia class]]) {
@@ -431,12 +439,12 @@ static NSMutableDictionary *authentifiedHosts;
             if (pathSub)
                 pathSub = [NSString stringWithFormat:@"http://%@/download/%@", hostName, pathSub];
             [mediaInXml addObject:[NSString stringWithFormat:@"<Media title=\"%@\" thumb=\"http://%@/Thumbnail/%@\" duration=\"%@\" size=\"%@\" pathfile=\"http://%@/download/%@\" pathSubtitle=\"%@\"/>",
-                                   file.title,
+                                   [file.title stringByAddingPercentEncodingWithAllowedCharacters:characterSet],
                                    hostName,
                                    file.thumbnail.path,
                                    [file mediaDuration], [file formatSize],
                                    hostName,
-                                   [[file mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:NSCharacterSet.URLFragmentAllowedCharacterSet], pathSub]];
+                                   [[file mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:characterSet], pathSub]];
         } else if ([mediaObject isKindOfClass:[VLCMLPlaylist class]]) {
             VLCMLPlaylist *playlist = (VLCMLPlaylist *)mediaObject;
             NSArray *playlistItems = [playlist media];
@@ -444,31 +452,33 @@ static NSMutableDictionary *authentifiedHosts;
                 NSString *pathSub = [self _checkIfSubtitleWasFound:[file mainFile].mrl.path];
                 if (pathSub)
                     pathSub = [NSString stringWithFormat:@"http://%@/download/%@", hostName, pathSub];
-                [mediaInXml addObject:[NSString stringWithFormat:@"<Media title=\"%@\" thumb=\"http://%@/Thumbnail/%@\" duration=\"%@\" size=\"%@\" pathfile=\"http://%@/download/%@\" pathSubtitle=\"%@\"/>", file.title,
+                [mediaInXml addObject:[NSString stringWithFormat:@"<Media title=\"%@\" thumb=\"http://%@/Thumbnail/%@\" duration=\"%@\" size=\"%@\" pathfile=\"http://%@/download/%@\" pathSubtitle=\"%@\"/>",
+                                       [file.title stringByAddingPercentEncodingWithAllowedCharacters:characterSet],
                                        hostName,
                                        file.thumbnail.path,
                                        [file mediaDuration],
                                        [file formatSize],
                                        hostName,
-                                       [[file mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:NSCharacterSet.URLFragmentAllowedCharacterSet], pathSub]];
+                                       [[file mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:characterSet], pathSub]];
             }
         } else if ([mediaObject isKindOfClass:[VLCMLAlbum class]]) {
             VLCMLAlbum *album = (VLCMLAlbum *)mediaObject;
             NSArray *albumTracks = [album tracks];
             for (VLCMLMedia *track in albumTracks) {
 
-                [mediaInXml addObject:[NSString stringWithFormat:@"<Media title=\"%@\" thumb=\"http://%@/Thumbnail/%@\" duration=\"%@\" size=\"%@\" pathfile=\"http://%@/download/%@\" pathSubtitle=\"\"/>", track.title,
+                [mediaInXml addObject:[NSString stringWithFormat:@"<Media title=\"%@\" thumb=\"http://%@/Thumbnail/%@\" duration=\"%@\" size=\"%@\" pathfile=\"http://%@/download/%@\" pathSubtitle=\"\"/>",
+                                       [track.title stringByAddingPercentEncodingWithAllowedCharacters:characterSet],
                                        hostName,
                                        track.thumbnail.path,
                                        [track mediaDuration],
                                        [track formatSize],
                                        hostName,
-                                       [[track mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:NSCharacterSet.URLFragmentAllowedCharacterSet]]];
+                                       [[track mainFile].mrl.path stringByAddingPercentEncodingWithAllowedCharacters:characterSet]]];
             }
         }
     } // end of forloop
 
-    NSDictionary *replacementDict = @{@"FILES" : [mediaInXml componentsJoinedByString:@" "],
+    NSDictionary *replacementDict = @{@"FILES" : [mediaInXml componentsJoinedByString:@"\n"],
                         @"NB_FILE" : [NSString stringWithFormat:@"%li", (unsigned long)mediaInXml.count],
                         @"LIB_TITLE" : [[UIDevice currentDevice] name]};
 
@@ -719,6 +729,10 @@ static NSMutableDictionary *authentifiedHosts;
 #if TARGET_OS_TV
 - (void)startPlaybackOfPath:(NSString *)path
 {
+    if (!path) {
+        return;
+    }
+
     APLog(@"Starting playback of %@", path);
     if (_receivedFiles == nil)
         _receivedFiles = [[NSMutableArray alloc] init];
